@@ -8,8 +8,8 @@
 /* Machine byte-order */
 #define Q_BIG_ENDIAN 4321
 #define Q_LITTLE_ENDIAN 1234
-#define QT_BUILD_KEY "x86_64 cygwin g++-4 full-config"
-#define QT_BUILD_KEY_COMPAT "x86_64 CYGWIN_NT-10.0 g++-4 full-config"
+#define QT_BUILD_KEY "i386 cygwin g++-4 full-config"
+#define QT_BUILD_KEY_COMPAT "i686 CYGWIN_NT-10.0-WOW g++-4 full-config"
 
 #ifdef QT_BOOTSTRAPPED
 #define Q_BYTE_ORDER Q_LITTLE_ENDIAN
@@ -18,12 +18,12 @@
 #endif
 /* Machine Architecture */
 #ifndef QT_BOOTSTRAPPED
-# define QT_ARCH_X86_64
+# define QT_ARCH_I386
 #else
-# define QT_ARCH_X86_64
+# define QT_ARCH_I386
 #endif
 /* Compile time features */
-#define QT_POINTER_SIZE 8
+#define QT_POINTER_SIZE 4
 
 #ifndef QT_BOOTSTRAPPED
 
